==> calendar-v1.7.20.zip: calendar/messages/sl/base.php <==
<?php

return [
    'Title' => 'Naslov',
    'disabled' => 'onemogočeno',
    '<strong>Add</strong> profile calendar' => '',
    '<strong>Choose</strong> target calendar' => '',
    '<strong>Reminder</strong> settings' => '',
    'Add all Space members with status {status}' => '',
    'Add participants...' => '',
    'Added: {users}' => '',
    'Additional Information for participants' => '',
    'Adds a calendar for private or public events to your profile and main menu.' => '',
    'Adds an event calendar to this space.' => '',
    'After (occurrences)' => '',
    'All Day' => '',
    'Allow option \'Decline\'' => '',
    'Allow option \'Undecided\'' => '',
    'Allows the user to create new calendar entries' => '',
    'Allows the user to edit/delete existing calendar entries' => '',
    'Attending' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'Birthday' => '',
    'CalDAV' => '',
    'Calendar' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Cancel Event' => '',
    'Cannot remove the participant!' => '',
    'Create entry' => '',
    'Custom reminder' => '',
    'Day' => '',
    'Days' => '',
    'Default reminder settings' => '',
    'Delete all events' => '',
    'Deleted' => '',
    'Description' => '',
    'Display events within the next X days' => '',
    'Do you want to install this module on your profile?' => '',
    'Download ICS' => '',
    'Edit' => '',
    'Edit Event' => '',
    'Edit all events' => '',
    'Edit this and following events' => '',
    'Edit this event' => '',
    'Email' => '',
    'Enable' => '',
    'Enable Reminder' => '',
    'End' => '',
    'End Date' => '',
    'End Time' => '',
    'End time must be after start time!' => '',
    'Event' => '',
    'Event Type' => '',
    'Event Types' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Event not found!' => '',
    'Export as {type}' => '',
    'Files' => '',
    'Filter by types' => '',
    'Friday' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Here you can configure default settings for all calendar events.' => '',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => '',
    'Hour' => '',
    'I\'m attending' => '',
    'ID' => '',
    'In order to add events to your profile, you have to enable the calendar module first.' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'Interested' => '',
    'Invalid date or time format!' => '',
    'Invalid day of month given' => '',
    'Invalid event type id selected.' => '',
    'Invalid frequency given' => '',
    'Invalid interval given' => '',
    'Invalid week day selection' => '',
    'Invite' => '',
    'Invited: {users}' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'List' => '',
    'Location' => '',
    'Manage entries' => '',
    'Maximum number of participants' => '',
    'Minute' => '',
    'Mode' => '',
    'Monday' => '',
    'Month' => '',
    'Monthly on day {dayOfMonth}' => '',
    'Monthly on the {position} {dayOfWeek}' => '',
    'Months' => '',
    'Never' => '',
    'Next' => '',
    'No new participants were added.' => '',
    'No new participants were invited.' => '',
    'No reminder' => '',
    'Notify participants about changes' => '',
    'On date' => '',
    'Participant removed.' => '',
    'Participants' => '',
    'Participation Status' => '',
    'Please select new participants.' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Profile Calendar' => '',
    'Public' => '',
    'Recurring' => '',
    'Reopen Event' => '',
    'Repeat every' => '',
    'Saturday' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Set reminder' => '',
    'Show past events' => '',
    'Sorting' => '',
    'Start Date' => '',
    'Start Time' => '',
    'Status cannot be updated.' => '',
    'Status updated.' => '',
    'Sunday' => '',
    'The event has already ended.' => '',
    'This event does not support recurrent events' => '',
    'Thursday' => '',
    'Time Zone' => '',
    'Today' => '',
    'Tuesday' => '',
    'Upcoming {type}' => '',
    'Upcoming {type}: {title}' => '',
    'Use default reminder' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'User birthdays' => '',
    'Wednesday' => '',
    'Week' => '',
    'Weeks' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'Year' => '',
    'Years' => '',
    'You cannot invite participants!' => '',
    'You don\'t have permission to delete this event!' => '',
    'You have an <strong>{type}</strong> coming up' => '',
    'You have an <strong>{type}</strong> coming up: {title}' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => '',
    'canceled' => '',
    'first' => '',
    'forth' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    'last' => '',
    'on weekdays' => '',
    'second' => '',
    'third' => '',
    '{displayName} Birthday' => '',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} added you to the event "{contentTitle}".' => '',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} invited you to the event "{contentTitle}".' => '',
    '{name} Calendar' => '',
];

==> calendar-v1.8.3.zip: calendar/messages/sl/base.php <==
<?php

return [
    'Edit' => 'Uredi',
    'Enable' => 'Omogoči',
    'Files' => 'Datoteke',
    'Never' => 'Nikoli',
    'Next' => 'Naslednji',
    'Time Zone' => 'Časovni pas',
    'Title' => 'Naslov',
    'disabled' => 'onemogočeno',
    '<strong>Add</strong> profile calendar' => '',
    '<strong>Choose</strong> target calendar' => '',
    '<strong>Reminder</strong> settings' => '',
    'Add all Space members with status {status}' => '',
    'Add participants...' => '',
    'Added: {users}' => '',
    'Additional Information for participants' => '',
    'Adds a calendar for private or public events to your profile and main menu.' => '',
    'Adds an event calendar to this space.' => '',
    'After (occurrences)' => '',
    'All Day' => '',
    'Allow option \'Decline\'' => '',
    'Allow option \'Undecided\'' => '',
    'Allows the user to create new calendar entries' => '',
    'Allows the user to edit/delete existing calendar entries' => '',
    'Attending' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'Birthday' => '',
    'CalDAV' => '',
    'Calendar' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Cancel Event' => '',
    'Cannot remove the participant!' => '',
    'Create entry' => '',
    'Custom reminder' => '',
    'Day' => '',
    'Days' => '',
    'Default reminder settings' => '',
    'Delete all events' => '',
    'Deleted' => '',
    'Description' => '',
    'Display events within the next X days' => '',
    'Do you want to install this module on your profile?' => '',
    'Download ICS' => '',
    'Edit Event' => '',
    'Edit all events' => '',
    'Edit this and following events' => '',
    'Edit this event' => '',
    'Email' => '',
    'Enable Reminder' => '',
    'End' => '',
    'End Date' => '',
    'End Time' => '',
    'End time must be after start time!' => '',
    'Event' => '',
    'Event Type' => '',
    'Event Types' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Event not found!' => '',
    'Export as {type}' => '',
    'Filter' => '',
    'Filter by types' => '',
    'Friday' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Here you can configure default settings for all calendar events.' => '',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Hour' => '',
    'I\'m attending' => '',
    'ID' => '',
    'In order to add events to your profile, you have to enable the calendar module first.' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'Interested' => '',
    'Invalid date or time format!' => '',
    'Invalid day of month given' => '',
    'Invalid event type id selected.' => '',
    'Invalid frequency given' => '',
    'Invalid interval given' => '',
    'Invalid week day selection' => '',
    'Invite' => '',
    'Invited: {users}' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'List' => '',
    'Location' => '',
    'Manage entries' => '',
    'Maximum number of participants' => '',
    'Minute' => '',
    'Mode' => '',
    'Monday' => '',
    'Month' => '',
    'Monthly on day {dayOfMonth}' => '',
    'Monthly on the {position} {dayOfWeek}' => '',
    'Months' => '',
    'No new participants were added.' => '',
    'No new participants were invited.' => '',
    'No reminder' => '',
    'Notify participants about changes' => '',
    'On date' => '',
    'Participant removed.' => '',
    'Participants' => '',
    'Participation Status' => '',
    'Please select new participants.' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Profile Calendar' => '',
    'Public' => '',
    'Recurring' => '',
    'Reopen Event' => '',
    'Repeat every' => '',
    'Saturday' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Set reminder' => '',
    'Show past events' => '',
    'Sorting' => '',
    'Start Date' => '',
    'Start Time' => '',
    'Status cannot be updated.' => '',
    'Status updated.' => '',
    'Sunday' => '',
    'The event has already ended.' => '',
    'This event does not support recurrent events' => '',
    'Thursday' => '',
    'Today' => '',
    'Tuesday' => '',
    'Upcoming {type}' => '',
    'Upcoming {type}: {title}' => '',
    'Use default reminder' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'User birthdays' => '',
    'Wednesday' => '',
    'Week' => '',
    'Weeks' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'Year' => '',
    'Years' => '',
    'You cannot invite participants!' => '',
    'You don\'t have permission to delete this event!' => '',
    'You have an <strong>{type}</strong> coming up' => '',
    'You have an <strong>{type}</strong> coming up: {title}' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => '',
    'canceled' => '',
    'first' => '',
    'forth' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    'last' => '',
    'on weekdays' => '',
    'second' => '',
    'third' => '',
    '{displayName} Birthday' => '',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} added you to the event "{contentTitle}".' => '',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '',
    '{displayName} invited you to the event "{contentTitle}".' => '',
    '{name} Calendar' => '',
];
